pub struct BLEConnDesc(/* private fields */);Implementations
Sourceimpl BLEConnDesc
impl BLEConnDesc
Sourcepub fn address(&self) -> BLEAddress
pub fn address(&self) -> BLEAddress
Gets the over-the-air address of the connected peer
Sourcepub fn id_address(&self) -> BLEAddress
pub fn id_address(&self) -> BLEAddress
Gets the ID address of the connected peer
Sourcepub fn conn_handle(&self) -> u16
pub fn conn_handle(&self) -> u16
Gets the connection handle of the connected peer
Sourcepub fn interval(&self) -> u16
pub fn interval(&self) -> u16
Gets the connection interval for this connection (in 1.25ms units)
Sourcepub fn latency(&self) -> u16
pub fn latency(&self) -> u16
Gets the allowable latency for this connection (unit = number of intervals)
Sourcepub fn mtu(&self) -> u16
pub fn mtu(&self) -> u16
Gets the maximum transmission unit size for this connection (in bytes)
Sourcepub fn authenticated(&self) -> bool
pub fn authenticated(&self) -> bool
Check if the the connection has been authenticated
Sourcepub fn sec_key_size(&self) -> u32
pub fn sec_key_size(&self) -> u32
Gets the key size used to encrypt the connection